@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '2.006000'; # VERSION
+our $VERSION = '2.006001'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -19,7 +19,7 @@ sub mvp_multivalue_args { return ( qw( stopwords directories ) ) }
 has wordlist => (
 	is      => 'ro',
 	isa     => 'Str',
-	default => 'Pod::Wordlist::hanekomu',    # default to original
+	default => 'Pod::Wordlist',
 );
 
 has spell_cmd => (
@@ -132,7 +132,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.006000
+version 2.006001
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ C<bin> and C<lib> are set by default.
 The module name of a word list you wish to use that works with
 L<Test::Spelling>.
 
-Defaults to L<Pod::Wordlist::hanekomu>.
+Defaults to L<Pod::Wordlist>.
 
 =head2 spell_cmd
 
@@ -212,6 +212,28 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Breno G. de Oliveira <garu@cpan.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Harley Pig <harleypig@gmail.com>
+
+=item *
+
+Randy Stauner <rwstauner@cpan.org>
+
+=back
+
 =head1 AUTHORS
 
 =over 4
@@ -222,15 +244,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =item *
 
-Randy Stauner <rwstauner@cpan.org>
-
-=item *
-
-Marcel Gruenauer <marcel@cpan.org>
-
-=item *
-
-Harley Pig <harleypig@gmail.com>
+Marcel Gruenauer <hanekomu@gmail.com>
 
 =back
 
@@ -251,7 +265,8 @@ use warnings;
 use Test::More;
 
 # generated by {{ $name }} {{ $version }}
-eval "use Test::Spelling 0.12; use {{ $wordlist }}; 1" or die $@;
+use Test::Spelling 0.12;
+use {{ $wordlist }};
 
 {{ $set_spell_cmd }}
 {{ $add_stopwords }}
